package ins;
import java.util.Iterator;

public interface Insieme extends Iterable<Integer> {

	/**
	 * Svuota l'insieme
	 */
	void clear();

	/**
	 * Verifica che l'insieme sia vuoto.
	 * 
	 * @return true se l'insieme e vuoto false altrimenti.
	 */
	boolean isEmpty();

	/**
	 * @return il numero di oggetti presenti nell'insieme
	 */
	int size();


	/**
	 * Inserisce un int nell'insieme
	 * 
	 * @param x
	 *            l'intero da inserire.
	 * @return true se l'intero non era già presente, false altrimenti
	 * @exception IllegalArgumentException
	 *                se x<0
	 */
	boolean put(int x);

	/**
	 * Controlla se un intero è presente
	 * 
	 * @return true se l'intero è presente, false altrimenti
	 */
	boolean contains(int x);

	/**
	 * Rimuove un int nell'insieme.
	 * 
	 * @param x
	 *            l'intero da rimuovere.
	 * @return true se l'intero era presente, false altrimenti
	 */
	boolean remove(int x);

	/**
	 * Conversione in String Restituisce una String con gli elementi
	 * dell'insieme in ordine crescente racchiusi tra parentesi quadre e
	 * separati da virgole
	 * 
	 * @return la stringa
	 */
	String toString();


	/**
	 * Restituisce un iteratore per scandire gli elementi dell'insieme in ordine
	 * crescente
	 * 
	 * @return l'iteratore
	 * @exception ConcurrentModificationException
	 *                se si usa next() e l'insieme è stata modificato
	 * @exception UnsupportedOperationException
	 *                se si usa remove()
	 */
	Iterator<Integer> iterator();
}
